@@ -8,11 +8,10 @@
 
 package Rex::Cloud::Amazon;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.14.0'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Cloud::Base;
