@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -28,10 +26,10 @@ All these functions are not idempotent.
 
 package Rex::Commands::Kernel;
 
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
