@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -31,11 +29,10 @@ With this module you can install packages and files.
 
 package Rex::Commands::Pkg;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.3'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 use Rex::Pkg;
 use Rex::Logger;
@@ -60,7 +57,7 @@ use vars qw(@EXPORT);
 @EXPORT =
   qw(install update remove update_system installed_packages is_installed update_package_db repository package_provider_for pkg);
 
-=head2 pkg($package, %options)
+=head2 pkg($package [, %options])
 
 Since: 0.45
 
