@@ -46,11 +46,10 @@ This module can sync directories between your Rex system and your servers withou
 
 package Rex::Commands::Sync;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.14.0'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 require Rex::Exporter;
 use base qw(Rex::Exporter);
