@@ -1,15 +1,13 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Group::Entry::Server;
 
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::System;
@@ -17,8 +15,9 @@ use Rex::Config;
 use Rex::Interface::Exec;
 use Data::Dumper;
 use Sort::Naturally;
+use Symbol;
 
-use List::MoreUtils qw(uniq);
+use List::Util 1.45 qw(uniq);
 
 use overload
   'eq'  => sub { shift->is_eq(@_); },
@@ -31,9 +30,8 @@ use attributes;
 sub function {
   my ( $class, $name, $code ) = @_;
 
-  no strict "refs"; ## no critic ProhibitNoStrict
-  *{ $class . "::" . $name } = $code;
-  use strict;
+  my $ref_to_function = qualify_to_ref( $name, $class );
+  *{$ref_to_function} = $code;
 }
 
 sub new {
