@@ -4,11 +4,10 @@
 
 package Rex::Helper::Run;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.14.0'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 require Exporter;
 use base qw(Exporter);
