@@ -1,18 +1,15 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Interface::Exec::Base;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 use Carp;
 use Rex::Helper::Run;
 
-our $VERSION = '1.13.3'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 sub new {
   my $that  = shift;
