@@ -1,16 +1,14 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Inventory::DMIDecode;
 
-use strict;
+use v5.12.5;
 use warnings;
 use Data::Dumper;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 use Rex::Inventory::DMIDecode::BaseBoard;
 use Rex::Inventory::DMIDecode::Bios;
