@@ -4,12 +4,11 @@
 
 package Rex::Inventory::Hal::Object::Volume;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 use Data::Dumper;
 
-our $VERSION = '1.14.0'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 use Rex::Inventory::Hal::Object;
 use base qw(Rex::Inventory::Hal::Object);
