@@ -1,15 +1,13 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Inventory::SMBios::Section;
 
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 require Exporter;
 use base qw(Exporter);
@@ -41,7 +39,7 @@ sub has {
     $item = [$_tmp];
   }
 
-  no strict 'refs'; ## no critic ProhibitNoStrict
+  no strict 'refs';
 
   for my $_itm ( @{$item} ) {
     my ( $itm, $from );
@@ -87,7 +85,7 @@ sub get_all {
   use Data::Dumper;
   my $r = ref($self);
 
-  no strict 'refs'; ## no critic ProhibitNoStrict
+  no strict 'refs';
   my @items = @{"${r}::items"};
   use strict;
 
@@ -150,4 +148,3 @@ sub get_index {
 }
 
 1;
-
