@@ -4,8 +4,7 @@
 
 package Rex::Output;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
 my $handle;
@@ -16,7 +15,7 @@ END   { IPC::Shareable->clean_up_all; }
 
 use base 'Rex::Output::Base';
 
-our $VERSION = '1.14.0'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 sub get {
   my ( $class, $output_module ) = @_;
