@@ -1,16 +1,13 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Output::JUnit;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 use Data::Dumper;
 use Rex::Template;
@@ -102,4 +99,3 @@ __DATA__
    <% } %>
   </testsuite>
 </testsuites>
-
