@@ -7,11 +7,10 @@
 
 package Rex::Pkg::OpenWrt;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.14.0'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 use Rex::Helper::Run;
 use Rex::Commands::File;
