@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -95,12 +93,11 @@ This module does not support any environment variables.
 
 package Rex::Template;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 use Symbol;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 use Rex::Config;
 use Rex::Logger;
