@@ -1,20 +1,17 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Test;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 use Rex -base;
 use Data::Dumper;
 use Rex::Commands::Box;
 require Rex::CLI;
 
-our $VERSION = '1.13.3'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 BEGIN {
   use Rex::Shared::Var;
