@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -52,13 +50,12 @@ This is a basic test module to test your code with the help of local VMs. You ca
 
 package Rex::Test::Base;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
 use base 'Test::Builder::Module';
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 require Rex::Commands;
 use Rex::Commands::Box;
