@@ -1,16 +1,13 @@
 #
 # (c) Oleg Hardt <litwol@litwol.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Virtualization::Lxc::attach;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.14.1'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -59,4 +56,3 @@ sub _format_opts {
 }
 
 1;
-
