@@ -1,4 +1,8 @@
 package t::tasks::cowbefore;
+
+use v5.12.5;
+use warnings;
+
 use Rex -base;
 
 desc "bring in the cattle";
